@@ -29,6 +29,7 @@ from subprocess import Popen, PIPE
 from itertools import *
 from functools import partial
 from calculate.lib.datavars import VariableError
+from .datavars import DataVarsInstall
 
 from calculate.lib.utils.mount import isMount, Btrfs, BtrfsError
 from calculate.lib.utils.files import (removeDir,
@@ -645,11 +646,7 @@ class DirectoryDistributive(Distributive):
             {'name': 'run',
              'type': 'bind',
              'target': 'run/',
-             'source': '/run'},
-            {'name': 'efivars',
-             'type': 'efivarfs',
-             'target': 'sys/firmware/efi/efivars',
-             'source': 'efivarfs'}
+             'source': '/run'}
             ]
 
     def __init__(self, directory, parent=None, mdirectory=None):
@@ -670,6 +667,15 @@ class DirectoryDistributive(Distributive):
         :return:
         """
         if not self.system_mounted:
+            self.clVars = DataVarsInstall()
+            # Если в режиме EFI, добавить раздел efivarfs
+            if self.clVars.GetBool('install.os_install_uefi_set'):
+                self.data.append(
+                {'name': 'efivars',
+                 'type': 'efivarfs',
+                 'target': 'sys/firmware/efi/efivars',
+                 'source': 'efivarfs'}
+                )            
             for obj in (x for x in self.data if x['name'] not in skip):
                 target_path = path.join(self.directory, obj['target'])
                 if obj['type'] == 'bind':
